@@ -6,7 +6,7 @@ Version information constants and auxiliary functions.
 '''
 
 
-VERSION = (0, 1, 0)
+VERSION = (0, 2, 0)
 
 
 import os
@@ -45,4 +45,5 @@ __all__ = (VERSION, version, version_verbose)
 
 
 if __name__ == '__main__':
-    print version_verbose()
+    from sys import stdout
+    stdout.write(version_verbose())
